import Vue from 'vue';
import VueRouter from 'vue-router';
import store from '@/store/index';
const jwt = require('jsonwebtoken');
const originalPush = VueRouter.prototype.push;
VueRouter.prototype.push = function push(location) {
  return originalPush.call(this, location).catch((err) => err);
};
Vue.use(VueRouter);
const market = [
  {
    path: '/market/patentInfo/index',
    meta: { title: '专利检索' },
    component: () => import('../views/market/patentInfo/index.vue'),
  },
  {
    path: '/market/transfer/index',
    meta: { title: '专利转让' },
    component: () => import('../views/market/transfer/index.vue'),
  },
  {
    path: '/market/demand/index',
    meta: { title: '专利需求' },
    component: () => import('../views/market/demand/index.vue'),
  },
  {
    path: '/market/navigation/index',
    meta: { title: '专利导航' },
    component: () => import('../views/market/navigation/index.vue'),
  },
  {
    path: '/market/navigation/detail',
    meta: { title: '详细信息' },
    component: () => import('../views/market/navigation/detail.vue'),
  },
];
const service = [
  {
    path: '/service/notice/index',
    meta: { title: '政策资讯' },
    component: () => import('../views/service/notice/index.vue'),
  },
  {
    path: '/service/notice/detail',
    meta: { title: '详细信息' },
    component: () => import('../views/service/notice/detail.vue'),
  },
  {
    path: '/service/law/index',
    meta: { title: '法律法规' },
    component: () => import('../views/service/law/index.vue'),
  },
  {
    path: '/service/law/detail',
    meta: { title: '详细信息' },
    component: () => import('../views/service/law/detail.vue'),
  },
  {
    path: '/service/dimension/index',
    meta: { title: '研究报告' },
    component: () => import('../views/service/dimension/index.vue'),
  },
  {
    path: '/service/dimension/detail',
    meta: { title: '详细信息' },
    component: () => import('../views/service/dimension/detail.vue'),
  },
  {
    path: '/service/interflow/index',
    meta: { title: '使用指南' },
    component: () => import('../views/service/interflow/index.vue'),
  },
  {
    path: '/service/interflow/detail',
    meta: { title: '详细信息' },
    component: () => import('../views/service/interflow/detail.vue'),
  },
];
const account = [
  {
    path: '/account/center/index',
    meta: { title: '个人中心' },
    component: () => import('../views/account/center/index.vue'),
  },
];

const web = [
  {
    path: '/',
    name: 'index',
    meta: { title: '网站首页' },
    component: () => import('../views/index.vue'),
  },
  {
    path: '/login',
    meta: { title: '登录' },
    component: () => import('../views/login.vue'),
  },
  {
    path: '/register',
    meta: { title: '账户注册' },
    component: () => import('../views/register.vue'),
  },
  ...market,
  ...service,
  ...account,
];
const routes = [...web];
const router = new VueRouter({
  mode: 'history',
  base: process.env.VUE_APP_ROUTER,
  routes,
});
router.beforeEach((to, from, next) => {
  let openid = to.query.openid;
  sessionStorage.setItem('openid', openid);
  document.title = `${to.meta.title} `;
  const token = localStorage.getItem('token');
  if (to.path == '/account/center/index') {
    if (!token) {
      next(`/login?path=${to.path}`);
    } else {
      let user = jwt.decode(token);
      store.commit('setUser', user, { root: true });
      next();
    }
  } else {
    let user = jwt.decode(token);
    store.commit('setUser', user, { root: true });
    next();
  }
});

export default router;
